(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('svelte/internal')) :
    typeof define === 'function' && define.amd ? define(['svelte/internal'], factory) :
    (global = global || self, global.SvelteHeatmap = factory(global.internal));
}(this, (function (internal) { 'use strict';

    /**
     * Get the last day of the month.
     *
     * @param {Date} date
     *
     * @return {Date}
     */
    function getMonthEnd(date) {
        return new Date(date.getFullYear(), date.getMonth() + 1, 0);
    }

    /**
     * Get the first day of the month.
     *
     * @param {Date} date
     *
     * @return {Date}
     */
    function getMonthStart(date) {
        return new Date(date.getFullYear(), date.getMonth(), 1);
    }

    /**
     * Get the last day of the week.
     *
     * @param {Date} date
     *
     * @return {Date}
     */
    function getWeekEnd(date) {
        return new Date(date.getFullYear(), date.getMonth(), date.getDate() + (6 - date.getDay()));
    }

    /**
     * Return the week index of a date.
     *
     * @param {Date} date
     *
     * @return {number}
     */
    function getWeekIndex(date) {
        const firstWeekday = new Date(date.getFullYear(), date.getMonth(), 1).getDay();
        const offsetDate = date.getDate() + firstWeekday - 1;

        return Math.floor(offsetDate / 7);
    }

    /**
     * Get the first day of the week.
     *
     * @param {Date} date
     *
     * @return {Date}
     */
    function getWeekStart(date) {
        return new Date(date.getFullYear(), date.getMonth(), date.getDate() - date.getDay());
    }

    /**
     * Normalize to a javascript Date object.
     *
     * @param {Date|number|string} value
     *
     * @return {Date}
     */
    function normalizeDate(value) {
        if (value instanceof Date) {
            return value;
        }

        if (['number', 'string'].includes(typeof value)) {
            return new Date(value);
        }

        throw new Error('Invalid date value');
    }

    /**
     * Stringify a date.
     *
     * @param {Date} date
     * 
     * @return {string}
     */
    function stringifyDate(date) {
        return `${date.getFullYear()}-${String(date.getMonth() + 1).padStart(2, '0')}-${String(date.getDate()).padStart(2, '0')}`
    }

    /**
     * Divide a calendar into months.
     *
     * @param {Object}              options
     * @param {boolean}             options.allowOverflow
     * @param {Array<Object>}       options.calendar
     * @param {Date|string|number}  options.endDate
     * @param {Date|string|number}  options.startDate
     *
     * @return {Array<Array<Object>>} 
     */
    function chunkMonths({ allowOverflow, calendar, endDate, startDate }) {
        let prevMonth = -1;

        startDate = normalizeDate(startDate);
        endDate = normalizeDate(endDate);

        return calendar.reduce((acc, day) => {
            const currentMonth = day.date.getMonth();

            if (prevMonth !== currentMonth) {
                acc.push([]);
                prevMonth = currentMonth;
            }

            if (
                allowOverflow || (
                    (!startDate || day.date >= startDate) &&
                    (!endDate || day.date <= endDate)
                )
            ) {
                acc[acc.length - 1].push(day);
            }

            return acc;
        }, []);
    }

    /**
     * Divide a calendar into weeks.
     *
     * @param {Object}              options
     * @param {boolean}             options.allowOverflow
     * @param {Array<Object>}       options.calendar
     * @param {Date|string|number}  options.endDate
     * @param {Date|string|number}  options.startDate
     *
     * @return {Array<Array<Object>>} 
     */
    function chunkWeeks({ allowOverflow, calendar, endDate, startDate }) {
        startDate = normalizeDate(startDate);
        endDate = normalizeDate(endDate);

        return calendar.reduce((acc, day, index) => {
            if (index % 7 === 0) {
                acc.push([]);
            }

            if (
                allowOverflow || (
                    (!startDate || day.date >= startDate) &&
                    (!endDate || day.date <= endDate)
                )
            ) {
                acc[acc.length - 1].push(day);
            }

            return acc;
        }, []);
    }

    /**
     * Determine the first day rendered on the heatmap.
     *
     * @param {Object}              props
     * @param {Array<string>}       props.colors
     * @param {Array<Object>}       props.data
     * @param {string}              props.emptyColor
     * @param {Date|number|string}  props.endDate
     * @param {Date|number|string}  props.startDate
     * @param {string}              props.view
     *
     * @return {Date}
     */
    function getCalendar({ colors, data, emptyColor, endDate, startDate, view }) {
        startDate = startDate ? normalizeDate(startDate) : new Date();
        endDate = endDate ? normalizeDate(endDate) : new Date();

        if (view === 'monthly') {
            startDate = getMonthStart(startDate);
            endDate = getMonthEnd(endDate);
        } else {
            startDate = getWeekStart(startDate);
            endDate = getWeekEnd(endDate);
        }

        let max = 0;
        const startDayOfMonth = startDate.getDate();
        const totalDays = Math.floor((endDate - startDate) / 86400000) + 1; // 86400000 = 1000 * 60 * 60 * 24

        return new Array(totalDays)
            .fill()
            .map((x, offset) => {
                const day = getDay({ data, offset, startDate, startDayOfMonth });

                if (day.value > max) {
                    max = day.value;
                }

                return day;
            })
            .map(({ date, value }) => {
                let color = getColor({ colors, max, value }) || emptyColor;

                return { color, date, value }
            });
    }

    /**
     * Determine what color a value should be.
     *
     * @param {options}         options
     * @param {Array<string>}   options.colors
     * @param {number}          options.max
     * @param {number}          options.value
     *
     * @return {string|null}
     */
    function getColor({ colors, max, value }) {
        if (colors.length && value) {
            let color = colors[0];

            const intencity = value / max;

            for (let i = 1; i < colors.length; i++) {
                if (intencity < i / colors.length) {
                    return color;
                }
                
                color = colors[i];
            }

            return colors[colors.length - 1];
        }

        return null;
    }

    /**
     * Aggregate the value of each day.
     *
     * @param {Object}          options
     * @param {Array<Object>}   options.data
     * @param {number}          options.offset
     * @param {number}          options.startDayOfMonth
     * @param {Date}            options.startDate
     *
     * @return {Object}
     */
    function getDay({ data, offset, startDate, startDayOfMonth }) {
        const date = new Date(startDate);
        date.setDate(startDayOfMonth + offset);

        const nextDate = new Date(date);
        nextDate.setDate(date.getDate() + 1);

        const value = data.reduce((acc, obj) => {
            const datapoint = normalizeDate(obj.date);

            return datapoint >= date && datapoint < nextDate ? acc + obj.value : acc;
        }, 0);

        return { date, value };
    }

    /* src/views/Cell.svelte generated by Svelte v3.20.1 */

    function create_fragment(ctx) {
    	let rect;
    	let rect_data_date_value;

    	return {
    		c() {
    			rect = internal.svg_element("rect");
    			internal.attr(rect, "data-date", rect_data_date_value = stringifyDate(/*date*/ ctx[1]));
    			internal.attr(rect, "data-value", /*value*/ ctx[4]);
    			internal.attr(rect, "fill", /*color*/ ctx[0]);
    			internal.attr(rect, "height", /*size*/ ctx[3]);
    			internal.attr(rect, "rx", /*radius*/ ctx[2]);
    			internal.attr(rect, "width", /*size*/ ctx[3]);
    			internal.attr(rect, "x", /*x*/ ctx[5]);
    			internal.attr(rect, "y", /*y*/ ctx[6]);
    		},
    		m(target, anchor) {
    			internal.insert(target, rect, anchor);
    		},
    		p(ctx, [dirty]) {
    			if (dirty & /*date*/ 2 && rect_data_date_value !== (rect_data_date_value = stringifyDate(/*date*/ ctx[1]))) {
    				internal.attr(rect, "data-date", rect_data_date_value);
    			}

    			if (dirty & /*value*/ 16) {
    				internal.attr(rect, "data-value", /*value*/ ctx[4]);
    			}

    			if (dirty & /*color*/ 1) {
    				internal.attr(rect, "fill", /*color*/ ctx[0]);
    			}

    			if (dirty & /*size*/ 8) {
    				internal.attr(rect, "height", /*size*/ ctx[3]);
    			}

    			if (dirty & /*radius*/ 4) {
    				internal.attr(rect, "rx", /*radius*/ ctx[2]);
    			}

    			if (dirty & /*size*/ 8) {
    				internal.attr(rect, "width", /*size*/ ctx[3]);
    			}

    			if (dirty & /*x*/ 32) {
    				internal.attr(rect, "x", /*x*/ ctx[5]);
    			}

    			if (dirty & /*y*/ 64) {
    				internal.attr(rect, "y", /*y*/ ctx[6]);
    			}
    		},
    		i: internal.noop,
    		o: internal.noop,
    		d(detaching) {
    			if (detaching) internal.detach(rect);
    		}
    	};
    }

    function instance($$self, $$props, $$invalidate) {
    	let { color } = $$props;
    	let { date } = $$props;
    	let { radius } = $$props;
    	let { size } = $$props;
    	let { value } = $$props;
    	let { x } = $$props;
    	let { y } = $$props;

    	$$self.$set = $$props => {
    		if ("color" in $$props) $$invalidate(0, color = $$props.color);
    		if ("date" in $$props) $$invalidate(1, date = $$props.date);
    		if ("radius" in $$props) $$invalidate(2, radius = $$props.radius);
    		if ("size" in $$props) $$invalidate(3, size = $$props.size);
    		if ("value" in $$props) $$invalidate(4, value = $$props.value);
    		if ("x" in $$props) $$invalidate(5, x = $$props.x);
    		if ("y" in $$props) $$invalidate(6, y = $$props.y);
    	};

    	return [color, date, radius, size, value, x, y];
    }

    class Cell extends internal.SvelteComponent {
    	constructor(options) {
    		super();

    		internal.init(this, options, instance, create_fragment, internal.safe_not_equal, {
    			color: 0,
    			date: 1,
    			radius: 2,
    			size: 3,
    			value: 4,
    			x: 5,
    			y: 6
    		});
    	}
    }

    /* src/views/Month.svelte generated by Svelte v3.20.1 */

    function get_each_context(ctx, list, i) {
    	const child_ctx = ctx.slice();
    	child_ctx[13] = list[i];
    	return child_ctx;
    }

    // (2:4) {#each days as day}
    function create_each_block(ctx) {
    	let current;

    	const cell = new Cell({
    			props: {
    				color: /*day*/ ctx[13].color,
    				date: /*day*/ ctx[13].date,
    				radius: /*cellRadius*/ ctx[0],
    				size: /*cellSize*/ ctx[2],
    				value: /*day*/ ctx[13].value,
    				x: /*day*/ ctx[13].date.getDay() * /*cellRect*/ ctx[1],
    				y: getWeekIndex(/*day*/ ctx[13].date) * /*cellRect*/ ctx[1] + /*monthLabelHeight*/ ctx[7]
    			}
    		});

    	return {
    		c() {
    			internal.create_component(cell.$$.fragment);
    		},
    		m(target, anchor) {
    			internal.mount_component(cell, target, anchor);
    			current = true;
    		},
    		p(ctx, dirty) {
    			const cell_changes = {};
    			if (dirty & /*days*/ 8) cell_changes.color = /*day*/ ctx[13].color;
    			if (dirty & /*days*/ 8) cell_changes.date = /*day*/ ctx[13].date;
    			if (dirty & /*cellRadius*/ 1) cell_changes.radius = /*cellRadius*/ ctx[0];
    			if (dirty & /*cellSize*/ 4) cell_changes.size = /*cellSize*/ ctx[2];
    			if (dirty & /*days*/ 8) cell_changes.value = /*day*/ ctx[13].value;
    			if (dirty & /*days, cellRect*/ 10) cell_changes.x = /*day*/ ctx[13].date.getDay() * /*cellRect*/ ctx[1];
    			if (dirty & /*days, cellRect, monthLabelHeight*/ 138) cell_changes.y = getWeekIndex(/*day*/ ctx[13].date) * /*cellRect*/ ctx[1] + /*monthLabelHeight*/ ctx[7];
    			cell.$set(cell_changes);
    		},
    		i(local) {
    			if (current) return;
    			internal.transition_in(cell.$$.fragment, local);
    			current = true;
    		},
    		o(local) {
    			internal.transition_out(cell.$$.fragment, local);
    			current = false;
    		},
    		d(detaching) {
    			internal.destroy_component(cell, detaching);
    		}
    	};
    }

    // (13:4) {#if monthLabelHeight > 0}
    function create_if_block(ctx) {
    	let text_1;
    	let t_value = /*monthLabels*/ ctx[8][/*days*/ ctx[3][0].date.getMonth()] + "";
    	let t;

    	return {
    		c() {
    			text_1 = internal.svg_element("text");
    			t = internal.text(t_value);
    			internal.attr(text_1, "alignment-baseline", "hanging");
    			internal.attr(text_1, "fill", /*fontColor*/ ctx[4]);
    			internal.attr(text_1, "font-family", /*fontFamily*/ ctx[5]);
    			internal.attr(text_1, "font-size", /*fontSize*/ ctx[6]);
    			internal.attr(text_1, "x", "0");
    			internal.attr(text_1, "y", "0");
    		},
    		m(target, anchor) {
    			internal.insert(target, text_1, anchor);
    			internal.append(text_1, t);
    		},
    		p(ctx, dirty) {
    			if (dirty & /*monthLabels, days*/ 264 && t_value !== (t_value = /*monthLabels*/ ctx[8][/*days*/ ctx[3][0].date.getMonth()] + "")) internal.set_data(t, t_value);

    			if (dirty & /*fontColor*/ 16) {
    				internal.attr(text_1, "fill", /*fontColor*/ ctx[4]);
    			}

    			if (dirty & /*fontFamily*/ 32) {
    				internal.attr(text_1, "font-family", /*fontFamily*/ ctx[5]);
    			}

    			if (dirty & /*fontSize*/ 64) {
    				internal.attr(text_1, "font-size", /*fontSize*/ ctx[6]);
    			}
    		},
    		d(detaching) {
    			if (detaching) internal.detach(text_1);
    		}
    	};
    }

    function create_fragment$1(ctx) {
    	let g;
    	let each_1_anchor;
    	let g_transform_value;
    	let current;
    	let each_value = /*days*/ ctx[3];
    	let each_blocks = [];

    	for (let i = 0; i < each_value.length; i += 1) {
    		each_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));
    	}

    	const out = i => internal.transition_out(each_blocks[i], 1, 1, () => {
    		each_blocks[i] = null;
    	});

    	let if_block = /*monthLabelHeight*/ ctx[7] > 0 && create_if_block(ctx);

    	return {
    		c() {
    			g = internal.svg_element("g");

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].c();
    			}

    			each_1_anchor = internal.empty();
    			if (if_block) if_block.c();
    			internal.attr(g, "transform", g_transform_value = `translate(${/*translation*/ ctx[9]}, 0)`);
    		},
    		m(target, anchor) {
    			internal.insert(target, g, anchor);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].m(g, null);
    			}

    			internal.append(g, each_1_anchor);
    			if (if_block) if_block.m(g, null);
    			current = true;
    		},
    		p(ctx, [dirty]) {
    			if (dirty & /*days, cellRadius, cellSize, cellRect, getWeekIndex, monthLabelHeight*/ 143) {
    				each_value = /*days*/ ctx[3];
    				let i;

    				for (i = 0; i < each_value.length; i += 1) {
    					const child_ctx = get_each_context(ctx, each_value, i);

    					if (each_blocks[i]) {
    						each_blocks[i].p(child_ctx, dirty);
    						internal.transition_in(each_blocks[i], 1);
    					} else {
    						each_blocks[i] = create_each_block(child_ctx);
    						each_blocks[i].c();
    						internal.transition_in(each_blocks[i], 1);
    						each_blocks[i].m(g, each_1_anchor);
    					}
    				}

    				internal.group_outros();

    				for (i = each_value.length; i < each_blocks.length; i += 1) {
    					out(i);
    				}

    				internal.check_outros();
    			}

    			if (/*monthLabelHeight*/ ctx[7] > 0) {
    				if (if_block) {
    					if_block.p(ctx, dirty);
    				} else {
    					if_block = create_if_block(ctx);
    					if_block.c();
    					if_block.m(g, null);
    				}
    			} else if (if_block) {
    				if_block.d(1);
    				if_block = null;
    			}

    			if (!current || dirty & /*translation*/ 512 && g_transform_value !== (g_transform_value = `translate(${/*translation*/ ctx[9]}, 0)`)) {
    				internal.attr(g, "transform", g_transform_value);
    			}
    		},
    		i(local) {
    			if (current) return;

    			for (let i = 0; i < each_value.length; i += 1) {
    				internal.transition_in(each_blocks[i]);
    			}

    			current = true;
    		},
    		o(local) {
    			each_blocks = each_blocks.filter(Boolean);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				internal.transition_out(each_blocks[i]);
    			}

    			current = false;
    		},
    		d(detaching) {
    			if (detaching) internal.detach(g);
    			internal.destroy_each(each_blocks, detaching);
    			if (if_block) if_block.d();
    		}
    	};
    }

    function instance$1($$self, $$props, $$invalidate) {
    	let { cellGap } = $$props;
    	let { cellRadius } = $$props;
    	let { cellRect } = $$props;
    	let { cellSize } = $$props;
    	let { days } = $$props;
    	let { fontColor } = $$props;
    	let { fontFamily } = $$props;
    	let { fontSize } = $$props;
    	let { index } = $$props;
    	let { monthGap } = $$props;
    	let { monthLabelHeight } = $$props;
    	let { monthLabels } = $$props;

    	$$self.$set = $$props => {
    		if ("cellGap" in $$props) $$invalidate(10, cellGap = $$props.cellGap);
    		if ("cellRadius" in $$props) $$invalidate(0, cellRadius = $$props.cellRadius);
    		if ("cellRect" in $$props) $$invalidate(1, cellRect = $$props.cellRect);
    		if ("cellSize" in $$props) $$invalidate(2, cellSize = $$props.cellSize);
    		if ("days" in $$props) $$invalidate(3, days = $$props.days);
    		if ("fontColor" in $$props) $$invalidate(4, fontColor = $$props.fontColor);
    		if ("fontFamily" in $$props) $$invalidate(5, fontFamily = $$props.fontFamily);
    		if ("fontSize" in $$props) $$invalidate(6, fontSize = $$props.fontSize);
    		if ("index" in $$props) $$invalidate(11, index = $$props.index);
    		if ("monthGap" in $$props) $$invalidate(12, monthGap = $$props.monthGap);
    		if ("monthLabelHeight" in $$props) $$invalidate(7, monthLabelHeight = $$props.monthLabelHeight);
    		if ("monthLabels" in $$props) $$invalidate(8, monthLabels = $$props.monthLabels);
    	};

    	let translation;

    	$$self.$$.update = () => {
    		if ($$self.$$.dirty & /*cellRect, cellGap, monthGap, index*/ 7170) {
    			 $$invalidate(9, translation = (7 * cellRect - cellGap + monthGap) * index);
    		}
    	};

    	return [
    		cellRadius,
    		cellRect,
    		cellSize,
    		days,
    		fontColor,
    		fontFamily,
    		fontSize,
    		monthLabelHeight,
    		monthLabels,
    		translation,
    		cellGap,
    		index,
    		monthGap
    	];
    }

    class Month extends internal.SvelteComponent {
    	constructor(options) {
    		super();

    		internal.init(this, options, instance$1, create_fragment$1, internal.safe_not_equal, {
    			cellGap: 10,
    			cellRadius: 0,
    			cellRect: 1,
    			cellSize: 2,
    			days: 3,
    			fontColor: 4,
    			fontFamily: 5,
    			fontSize: 6,
    			index: 11,
    			monthGap: 12,
    			monthLabelHeight: 7,
    			monthLabels: 8
    		});
    	}
    }

    /* src/views/Week.svelte generated by Svelte v3.20.1 */

    function get_each_context$1(ctx, list, i) {
    	const child_ctx = ctx.slice();
    	child_ctx[7] = list[i];
    	child_ctx[6] = i;
    	return child_ctx;
    }

    // (2:4) {#each days as day, index}
    function create_each_block$1(ctx) {
    	let current;

    	const cell = new Cell({
    			props: {
    				color: /*day*/ ctx[7].color,
    				date: /*day*/ ctx[7].date,
    				radius: /*cellRadius*/ ctx[0],
    				size: /*cellSize*/ ctx[2],
    				value: /*day*/ ctx[7].value,
    				y: /*day*/ ctx[7].date.getDay() * /*cellRect*/ ctx[1]
    			}
    		});

    	return {
    		c() {
    			internal.create_component(cell.$$.fragment);
    		},
    		m(target, anchor) {
    			internal.mount_component(cell, target, anchor);
    			current = true;
    		},
    		p(ctx, dirty) {
    			const cell_changes = {};
    			if (dirty & /*days*/ 8) cell_changes.color = /*day*/ ctx[7].color;
    			if (dirty & /*days*/ 8) cell_changes.date = /*day*/ ctx[7].date;
    			if (dirty & /*cellRadius*/ 1) cell_changes.radius = /*cellRadius*/ ctx[0];
    			if (dirty & /*cellSize*/ 4) cell_changes.size = /*cellSize*/ ctx[2];
    			if (dirty & /*days*/ 8) cell_changes.value = /*day*/ ctx[7].value;
    			if (dirty & /*days, cellRect*/ 10) cell_changes.y = /*day*/ ctx[7].date.getDay() * /*cellRect*/ ctx[1];
    			cell.$set(cell_changes);
    		},
    		i(local) {
    			if (current) return;
    			internal.transition_in(cell.$$.fragment, local);
    			current = true;
    		},
    		o(local) {
    			internal.transition_out(cell.$$.fragment, local);
    			current = false;
    		},
    		d(detaching) {
    			internal.destroy_component(cell, detaching);
    		}
    	};
    }

    function create_fragment$2(ctx) {
    	let g;
    	let g_transform_value;
    	let current;
    	let each_value = /*days*/ ctx[3];
    	let each_blocks = [];

    	for (let i = 0; i < each_value.length; i += 1) {
    		each_blocks[i] = create_each_block$1(get_each_context$1(ctx, each_value, i));
    	}

    	const out = i => internal.transition_out(each_blocks[i], 1, 1, () => {
    		each_blocks[i] = null;
    	});

    	return {
    		c() {
    			g = internal.svg_element("g");

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].c();
    			}

    			internal.attr(g, "transform", g_transform_value = `translate(${/*translation*/ ctx[5]}, ${/*monthLabelHeight*/ ctx[4]})`);
    		},
    		m(target, anchor) {
    			internal.insert(target, g, anchor);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].m(g, null);
    			}

    			current = true;
    		},
    		p(ctx, [dirty]) {
    			if (dirty & /*days, cellRadius, cellSize, cellRect*/ 15) {
    				each_value = /*days*/ ctx[3];
    				let i;

    				for (i = 0; i < each_value.length; i += 1) {
    					const child_ctx = get_each_context$1(ctx, each_value, i);

    					if (each_blocks[i]) {
    						each_blocks[i].p(child_ctx, dirty);
    						internal.transition_in(each_blocks[i], 1);
    					} else {
    						each_blocks[i] = create_each_block$1(child_ctx);
    						each_blocks[i].c();
    						internal.transition_in(each_blocks[i], 1);
    						each_blocks[i].m(g, null);
    					}
    				}

    				internal.group_outros();

    				for (i = each_value.length; i < each_blocks.length; i += 1) {
    					out(i);
    				}

    				internal.check_outros();
    			}

    			if (!current || dirty & /*translation, monthLabelHeight*/ 48 && g_transform_value !== (g_transform_value = `translate(${/*translation*/ ctx[5]}, ${/*monthLabelHeight*/ ctx[4]})`)) {
    				internal.attr(g, "transform", g_transform_value);
    			}
    		},
    		i(local) {
    			if (current) return;

    			for (let i = 0; i < each_value.length; i += 1) {
    				internal.transition_in(each_blocks[i]);
    			}

    			current = true;
    		},
    		o(local) {
    			each_blocks = each_blocks.filter(Boolean);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				internal.transition_out(each_blocks[i]);
    			}

    			current = false;
    		},
    		d(detaching) {
    			if (detaching) internal.detach(g);
    			internal.destroy_each(each_blocks, detaching);
    		}
    	};
    }

    function instance$2($$self, $$props, $$invalidate) {
    	let { cellRadius } = $$props;
    	let { cellRect } = $$props;
    	let { cellSize } = $$props;
    	let { days } = $$props;
    	let { index } = $$props;
    	let { monthLabelHeight } = $$props;

    	$$self.$set = $$props => {
    		if ("cellRadius" in $$props) $$invalidate(0, cellRadius = $$props.cellRadius);
    		if ("cellRect" in $$props) $$invalidate(1, cellRect = $$props.cellRect);
    		if ("cellSize" in $$props) $$invalidate(2, cellSize = $$props.cellSize);
    		if ("days" in $$props) $$invalidate(3, days = $$props.days);
    		if ("index" in $$props) $$invalidate(6, index = $$props.index);
    		if ("monthLabelHeight" in $$props) $$invalidate(4, monthLabelHeight = $$props.monthLabelHeight);
    	};

    	let translation;

    	$$self.$$.update = () => {
    		if ($$self.$$.dirty & /*cellRect, index*/ 66) {
    			 $$invalidate(5, translation = cellRect * index);
    		}
    	};

    	return [cellRadius, cellRect, cellSize, days, monthLabelHeight, translation, index];
    }

    class Week extends internal.SvelteComponent {
    	constructor(options) {
    		super();

    		internal.init(this, options, instance$2, create_fragment$2, internal.safe_not_equal, {
    			cellRadius: 0,
    			cellRect: 1,
    			cellSize: 2,
    			days: 3,
    			index: 6,
    			monthLabelHeight: 4
    		});
    	}
    }

    /* src/SvelteHeatmap.svelte generated by Svelte v3.20.1 */

    function get_each_context_1(ctx, list, i) {
    	const child_ctx = ctx.slice();
    	child_ctx[26] = list[i];
    	child_ctx[28] = i;
    	return child_ctx;
    }

    function get_each_context_2(ctx, list, i) {
    	const child_ctx = ctx.slice();
    	child_ctx[30] = list[i];
    	child_ctx[28] = i;
    	return child_ctx;
    }

    function get_each_context$2(ctx, list, i) {
    	const child_ctx = ctx.slice();
    	child_ctx[26] = list[i];
    	child_ctx[28] = i;
    	return child_ctx;
    }

    // (19:4) {:else}
    function create_else_block(ctx) {
    	let g;
    	let g_transform_value;
    	let current;
    	let if_block = /*dayLabelWidth*/ ctx[3] > 0 && create_if_block_2(ctx);
    	let each_value_1 = /*chunks*/ ctx[13];
    	let each_blocks = [];

    	for (let i = 0; i < each_value_1.length; i += 1) {
    		each_blocks[i] = create_each_block_1(get_each_context_1(ctx, each_value_1, i));
    	}

    	const out = i => internal.transition_out(each_blocks[i], 1, 1, () => {
    		each_blocks[i] = null;
    	});

    	return {
    		c() {
    			if (if_block) if_block.c();
    			g = internal.svg_element("g");

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].c();
    			}

    			internal.attr(g, "transform", g_transform_value = `translate(${/*dayLabelWidth*/ ctx[3]})`);
    		},
    		m(target, anchor) {
    			if (if_block) if_block.m(target, anchor);
    			internal.insert(target, g, anchor);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].m(g, null);
    			}

    			current = true;
    		},
    		p(ctx, dirty) {
    			if (/*dayLabelWidth*/ ctx[3] > 0) {
    				if (if_block) {
    					if_block.p(ctx, dirty);
    				} else {
    					if_block = create_if_block_2(ctx);
    					if_block.c();
    					if_block.m(g.parentNode, g);
    				}
    			} else if (if_block) {
    				if_block.d(1);
    				if_block = null;
    			}

    			if (dirty[0] & /*fontColor, fontFamily, fontSize, cellRect, monthLabels, chunks, monthLabelHeight, isNewMonth, cellRadius, cellSize*/ 145126) {
    				each_value_1 = /*chunks*/ ctx[13];
    				let i;

    				for (i = 0; i < each_value_1.length; i += 1) {
    					const child_ctx = get_each_context_1(ctx, each_value_1, i);

    					if (each_blocks[i]) {
    						each_blocks[i].p(child_ctx, dirty);
    						internal.transition_in(each_blocks[i], 1);
    					} else {
    						each_blocks[i] = create_each_block_1(child_ctx);
    						each_blocks[i].c();
    						internal.transition_in(each_blocks[i], 1);
    						each_blocks[i].m(g, null);
    					}
    				}

    				internal.group_outros();

    				for (i = each_value_1.length; i < each_blocks.length; i += 1) {
    					out(i);
    				}

    				internal.check_outros();
    			}

    			if (!current || dirty[0] & /*dayLabelWidth*/ 8 && g_transform_value !== (g_transform_value = `translate(${/*dayLabelWidth*/ ctx[3]})`)) {
    				internal.attr(g, "transform", g_transform_value);
    			}
    		},
    		i(local) {
    			if (current) return;

    			for (let i = 0; i < each_value_1.length; i += 1) {
    				internal.transition_in(each_blocks[i]);
    			}

    			current = true;
    		},
    		o(local) {
    			each_blocks = each_blocks.filter(Boolean);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				internal.transition_out(each_blocks[i]);
    			}

    			current = false;
    		},
    		d(detaching) {
    			if (if_block) if_block.d(detaching);
    			if (detaching) internal.detach(g);
    			internal.destroy_each(each_blocks, detaching);
    		}
    	};
    }

    // (2:4) {#if view === 'monthly'}
    function create_if_block$1(ctx) {
    	let each_1_anchor;
    	let current;
    	let each_value = /*chunks*/ ctx[13];
    	let each_blocks = [];

    	for (let i = 0; i < each_value.length; i += 1) {
    		each_blocks[i] = create_each_block$2(get_each_context$2(ctx, each_value, i));
    	}

    	const out = i => internal.transition_out(each_blocks[i], 1, 1, () => {
    		each_blocks[i] = null;
    	});

    	return {
    		c() {
    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].c();
    			}

    			each_1_anchor = internal.empty();
    		},
    		m(target, anchor) {
    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].m(target, anchor);
    			}

    			internal.insert(target, each_1_anchor, anchor);
    			current = true;
    		},
    		p(ctx, dirty) {
    			if (dirty[0] & /*cellGap, cellRadius, cellRect, cellSize, chunks, fontColor, fontFamily, fontSize, monthGap, monthLabelHeight, monthLabels*/ 14311) {
    				each_value = /*chunks*/ ctx[13];
    				let i;

    				for (i = 0; i < each_value.length; i += 1) {
    					const child_ctx = get_each_context$2(ctx, each_value, i);

    					if (each_blocks[i]) {
    						each_blocks[i].p(child_ctx, dirty);
    						internal.transition_in(each_blocks[i], 1);
    					} else {
    						each_blocks[i] = create_each_block$2(child_ctx);
    						each_blocks[i].c();
    						internal.transition_in(each_blocks[i], 1);
    						each_blocks[i].m(each_1_anchor.parentNode, each_1_anchor);
    					}
    				}

    				internal.group_outros();

    				for (i = each_value.length; i < each_blocks.length; i += 1) {
    					out(i);
    				}

    				internal.check_outros();
    			}
    		},
    		i(local) {
    			if (current) return;

    			for (let i = 0; i < each_value.length; i += 1) {
    				internal.transition_in(each_blocks[i]);
    			}

    			current = true;
    		},
    		o(local) {
    			each_blocks = each_blocks.filter(Boolean);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				internal.transition_out(each_blocks[i]);
    			}

    			current = false;
    		},
    		d(detaching) {
    			internal.destroy_each(each_blocks, detaching);
    			if (detaching) internal.detach(each_1_anchor);
    		}
    	};
    }

    // (20:8) {#if dayLabelWidth > 0}
    function create_if_block_2(ctx) {
    	let each_1_anchor;
    	let each_value_2 = /*dayLabels*/ ctx[4];
    	let each_blocks = [];

    	for (let i = 0; i < each_value_2.length; i += 1) {
    		each_blocks[i] = create_each_block_2(get_each_context_2(ctx, each_value_2, i));
    	}

    	return {
    		c() {
    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].c();
    			}

    			each_1_anchor = internal.empty();
    		},
    		m(target, anchor) {
    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].m(target, anchor);
    			}

    			internal.insert(target, each_1_anchor, anchor);
    		},
    		p(ctx, dirty) {
    			if (dirty[0] & /*fontColor, fontFamily, fontSize, dayLabelPosition, dayLabels*/ 65776) {
    				each_value_2 = /*dayLabels*/ ctx[4];
    				let i;

    				for (i = 0; i < each_value_2.length; i += 1) {
    					const child_ctx = get_each_context_2(ctx, each_value_2, i);

    					if (each_blocks[i]) {
    						each_blocks[i].p(child_ctx, dirty);
    					} else {
    						each_blocks[i] = create_each_block_2(child_ctx);
    						each_blocks[i].c();
    						each_blocks[i].m(each_1_anchor.parentNode, each_1_anchor);
    					}
    				}

    				for (; i < each_blocks.length; i += 1) {
    					each_blocks[i].d(1);
    				}

    				each_blocks.length = each_value_2.length;
    			}
    		},
    		d(detaching) {
    			internal.destroy_each(each_blocks, detaching);
    			if (detaching) internal.detach(each_1_anchor);
    		}
    	};
    }

    // (21:12) {#each dayLabels as label, index}
    function create_each_block_2(ctx) {
    	let text_1;
    	let t_value = /*label*/ ctx[30] + "";
    	let t;
    	let text_1_y_value;

    	return {
    		c() {
    			text_1 = internal.svg_element("text");
    			t = internal.text(t_value);
    			internal.attr(text_1, "alignment-baseline", "middle");
    			internal.attr(text_1, "fill", /*fontColor*/ ctx[5]);
    			internal.attr(text_1, "font-family", /*fontFamily*/ ctx[6]);
    			internal.attr(text_1, "font-size", /*fontSize*/ ctx[7]);
    			internal.attr(text_1, "x", "0");
    			internal.attr(text_1, "y", text_1_y_value = /*dayLabelPosition*/ ctx[16](/*index*/ ctx[28]));
    		},
    		m(target, anchor) {
    			internal.insert(target, text_1, anchor);
    			internal.append(text_1, t);
    		},
    		p(ctx, dirty) {
    			if (dirty[0] & /*dayLabels*/ 16 && t_value !== (t_value = /*label*/ ctx[30] + "")) internal.set_data(t, t_value);

    			if (dirty[0] & /*fontColor*/ 32) {
    				internal.attr(text_1, "fill", /*fontColor*/ ctx[5]);
    			}

    			if (dirty[0] & /*fontFamily*/ 64) {
    				internal.attr(text_1, "font-family", /*fontFamily*/ ctx[6]);
    			}

    			if (dirty[0] & /*fontSize*/ 128) {
    				internal.attr(text_1, "font-size", /*fontSize*/ ctx[7]);
    			}

    			if (dirty[0] & /*dayLabelPosition*/ 65536 && text_1_y_value !== (text_1_y_value = /*dayLabelPosition*/ ctx[16](/*index*/ ctx[28]))) {
    				internal.attr(text_1, "y", text_1_y_value);
    			}
    		},
    		d(detaching) {
    			if (detaching) internal.detach(text_1);
    		}
    	};
    }

    // (43:16) {#if monthLabelHeight > 0 && isNewMonth(chunks, index)}
    function create_if_block_1(ctx) {
    	let text_1;
    	let t_value = /*monthLabels*/ ctx[10][/*chunk*/ ctx[26][0].date.getMonth()] + "";
    	let t;
    	let text_1_x_value;

    	return {
    		c() {
    			text_1 = internal.svg_element("text");
    			t = internal.text(t_value);
    			internal.attr(text_1, "alignment-baseline", "hanging");
    			internal.attr(text_1, "fill", /*fontColor*/ ctx[5]);
    			internal.attr(text_1, "font-family", /*fontFamily*/ ctx[6]);
    			internal.attr(text_1, "font-size", /*fontSize*/ ctx[7]);
    			internal.attr(text_1, "x", text_1_x_value = /*cellRect*/ ctx[12] * /*index*/ ctx[28]);
    		},
    		m(target, anchor) {
    			internal.insert(target, text_1, anchor);
    			internal.append(text_1, t);
    		},
    		p(ctx, dirty) {
    			if (dirty[0] & /*monthLabels, chunks*/ 9216 && t_value !== (t_value = /*monthLabels*/ ctx[10][/*chunk*/ ctx[26][0].date.getMonth()] + "")) internal.set_data(t, t_value);

    			if (dirty[0] & /*fontColor*/ 32) {
    				internal.attr(text_1, "fill", /*fontColor*/ ctx[5]);
    			}

    			if (dirty[0] & /*fontFamily*/ 64) {
    				internal.attr(text_1, "font-family", /*fontFamily*/ ctx[6]);
    			}

    			if (dirty[0] & /*fontSize*/ 128) {
    				internal.attr(text_1, "font-size", /*fontSize*/ ctx[7]);
    			}

    			if (dirty[0] & /*cellRect*/ 4096 && text_1_x_value !== (text_1_x_value = /*cellRect*/ ctx[12] * /*index*/ ctx[28])) {
    				internal.attr(text_1, "x", text_1_x_value);
    			}
    		},
    		d(detaching) {
    			if (detaching) internal.detach(text_1);
    		}
    	};
    }

    // (34:12) {#each chunks as chunk, index}
    function create_each_block_1(ctx) {
    	let show_if = /*monthLabelHeight*/ ctx[9] > 0 && /*isNewMonth*/ ctx[17](/*chunks*/ ctx[13], /*index*/ ctx[28]);
    	let if_block_anchor;
    	let current;

    	const week = new Week({
    			props: {
    				cellRadius: /*cellRadius*/ ctx[1],
    				cellRect: /*cellRect*/ ctx[12],
    				cellSize: /*cellSize*/ ctx[2],
    				days: /*chunk*/ ctx[26],
    				index: /*index*/ ctx[28],
    				monthLabelHeight: /*monthLabelHeight*/ ctx[9]
    			}
    		});

    	let if_block = show_if && create_if_block_1(ctx);

    	return {
    		c() {
    			internal.create_component(week.$$.fragment);
    			if (if_block) if_block.c();
    			if_block_anchor = internal.empty();
    		},
    		m(target, anchor) {
    			internal.mount_component(week, target, anchor);
    			if (if_block) if_block.m(target, anchor);
    			internal.insert(target, if_block_anchor, anchor);
    			current = true;
    		},
    		p(ctx, dirty) {
    			const week_changes = {};
    			if (dirty[0] & /*cellRadius*/ 2) week_changes.cellRadius = /*cellRadius*/ ctx[1];
    			if (dirty[0] & /*cellRect*/ 4096) week_changes.cellRect = /*cellRect*/ ctx[12];
    			if (dirty[0] & /*cellSize*/ 4) week_changes.cellSize = /*cellSize*/ ctx[2];
    			if (dirty[0] & /*chunks*/ 8192) week_changes.days = /*chunk*/ ctx[26];
    			if (dirty[0] & /*monthLabelHeight*/ 512) week_changes.monthLabelHeight = /*monthLabelHeight*/ ctx[9];
    			week.$set(week_changes);
    			if (dirty[0] & /*monthLabelHeight, chunks*/ 8704) show_if = /*monthLabelHeight*/ ctx[9] > 0 && /*isNewMonth*/ ctx[17](/*chunks*/ ctx[13], /*index*/ ctx[28]);

    			if (show_if) {
    				if (if_block) {
    					if_block.p(ctx, dirty);
    				} else {
    					if_block = create_if_block_1(ctx);
    					if_block.c();
    					if_block.m(if_block_anchor.parentNode, if_block_anchor);
    				}
    			} else if (if_block) {
    				if_block.d(1);
    				if_block = null;
    			}
    		},
    		i(local) {
    			if (current) return;
    			internal.transition_in(week.$$.fragment, local);
    			current = true;
    		},
    		o(local) {
    			internal.transition_out(week.$$.fragment, local);
    			current = false;
    		},
    		d(detaching) {
    			internal.destroy_component(week, detaching);
    			if (if_block) if_block.d(detaching);
    			if (detaching) internal.detach(if_block_anchor);
    		}
    	};
    }

    // (3:8) {#each chunks as chunk, index}
    function create_each_block$2(ctx) {
    	let current;

    	const month = new Month({
    			props: {
    				cellGap: /*cellGap*/ ctx[0],
    				cellRadius: /*cellRadius*/ ctx[1],
    				cellRect: /*cellRect*/ ctx[12],
    				cellSize: /*cellSize*/ ctx[2],
    				days: /*chunk*/ ctx[26],
    				fontColor: /*fontColor*/ ctx[5],
    				fontFamily: /*fontFamily*/ ctx[6],
    				fontSize: /*fontSize*/ ctx[7],
    				index: /*index*/ ctx[28],
    				monthGap: /*monthGap*/ ctx[8],
    				monthLabelHeight: /*monthLabelHeight*/ ctx[9],
    				monthLabels: /*monthLabels*/ ctx[10]
    			}
    		});

    	return {
    		c() {
    			internal.create_component(month.$$.fragment);
    		},
    		m(target, anchor) {
    			internal.mount_component(month, target, anchor);
    			current = true;
    		},
    		p(ctx, dirty) {
    			const month_changes = {};
    			if (dirty[0] & /*cellGap*/ 1) month_changes.cellGap = /*cellGap*/ ctx[0];
    			if (dirty[0] & /*cellRadius*/ 2) month_changes.cellRadius = /*cellRadius*/ ctx[1];
    			if (dirty[0] & /*cellRect*/ 4096) month_changes.cellRect = /*cellRect*/ ctx[12];
    			if (dirty[0] & /*cellSize*/ 4) month_changes.cellSize = /*cellSize*/ ctx[2];
    			if (dirty[0] & /*chunks*/ 8192) month_changes.days = /*chunk*/ ctx[26];
    			if (dirty[0] & /*fontColor*/ 32) month_changes.fontColor = /*fontColor*/ ctx[5];
    			if (dirty[0] & /*fontFamily*/ 64) month_changes.fontFamily = /*fontFamily*/ ctx[6];
    			if (dirty[0] & /*fontSize*/ 128) month_changes.fontSize = /*fontSize*/ ctx[7];
    			if (dirty[0] & /*monthGap*/ 256) month_changes.monthGap = /*monthGap*/ ctx[8];
    			if (dirty[0] & /*monthLabelHeight*/ 512) month_changes.monthLabelHeight = /*monthLabelHeight*/ ctx[9];
    			if (dirty[0] & /*monthLabels*/ 1024) month_changes.monthLabels = /*monthLabels*/ ctx[10];
    			month.$set(month_changes);
    		},
    		i(local) {
    			if (current) return;
    			internal.transition_in(month.$$.fragment, local);
    			current = true;
    		},
    		o(local) {
    			internal.transition_out(month.$$.fragment, local);
    			current = false;
    		},
    		d(detaching) {
    			internal.destroy_component(month, detaching);
    		}
    	};
    }

    function create_fragment$3(ctx) {
    	let svg;
    	let current_block_type_index;
    	let if_block;
    	let svg_viewBox_value;
    	let current;
    	const if_block_creators = [create_if_block$1, create_else_block];
    	const if_blocks = [];

    	function select_block_type(ctx, dirty) {
    		if (/*view*/ ctx[11] === "monthly") return 0;
    		return 1;
    	}

    	current_block_type_index = select_block_type(ctx);
    	if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);

    	return {
    		c() {
    			svg = internal.svg_element("svg");
    			if_block.c();
    			internal.attr(svg, "viewBox", svg_viewBox_value = `0 0 ${/*width*/ ctx[15]} ${/*height*/ ctx[14]}`);
    		},
    		m(target, anchor) {
    			internal.insert(target, svg, anchor);
    			if_blocks[current_block_type_index].m(svg, null);
    			current = true;
    		},
    		p(ctx, dirty) {
    			let previous_block_index = current_block_type_index;
    			current_block_type_index = select_block_type(ctx);

    			if (current_block_type_index === previous_block_index) {
    				if_blocks[current_block_type_index].p(ctx, dirty);
    			} else {
    				internal.group_outros();

    				internal.transition_out(if_blocks[previous_block_index], 1, 1, () => {
    					if_blocks[previous_block_index] = null;
    				});

    				internal.check_outros();
    				if_block = if_blocks[current_block_type_index];

    				if (!if_block) {
    					if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);
    					if_block.c();
    				}

    				internal.transition_in(if_block, 1);
    				if_block.m(svg, null);
    			}

    			if (!current || dirty[0] & /*width, height*/ 49152 && svg_viewBox_value !== (svg_viewBox_value = `0 0 ${/*width*/ ctx[15]} ${/*height*/ ctx[14]}`)) {
    				internal.attr(svg, "viewBox", svg_viewBox_value);
    			}
    		},
    		i(local) {
    			if (current) return;
    			internal.transition_in(if_block);
    			current = true;
    		},
    		o(local) {
    			internal.transition_out(if_block);
    			current = false;
    		},
    		d(detaching) {
    			if (detaching) internal.detach(svg);
    			if_blocks[current_block_type_index].d();
    		}
    	};
    }

    function instance$3($$self, $$props, $$invalidate) {
    	let { allowOverflow = false } = $$props;
    	let { cellGap = 2 } = $$props;
    	let { cellRadius = 0 } = $$props;
    	let { cellSize = 10 } = $$props;
    	let { colors = ["#c6e48b", "#7bc96f", "#239a3b", "#196127"] } = $$props;
    	let { data = [] } = $$props;
    	let { dayLabelWidth = 20 } = $$props;
    	let { dayLabels = ["", "Mon", "", "Wed", "", "Fri", ""] } = $$props;
    	let { emptyColor = "#ebedf0" } = $$props;
    	let { endDate = null } = $$props;
    	let { fontColor = "#333" } = $$props;
    	let { fontFamily = "sans-serif" } = $$props;
    	let { fontSize = 8 } = $$props;
    	let { monthGap = 2 } = $$props;
    	let { monthLabelHeight = 12 } = $$props;

    	let { monthLabels = [
    		"Jan",
    		"Feb",
    		"Mar",
    		"Apr",
    		"May",
    		"Jun",
    		"Jul",
    		"Aug",
    		"Sep",
    		"Oct",
    		"Nov",
    		"Dec"
    	] } = $$props;

    	let { startDate = null } = $$props;
    	let { view = "weekly" } = $$props;

    	const isNewMonth = (chunks, index) => {
    		const chunk = chunks[index];
    		const prev = chunks[index - 1];

    		if (!prev) {
    			return true;
    		}

    		if (!prev.length || !chunk.length) {
    			return false;
    		}

    		const currentIndex = chunk[0].date.getMonth();
    		const prevIndex = prev[0].date.getMonth();
    		return index < chunks.length && index < chunks.length - 1 && (currentIndex > prevIndex || currentIndex === 0 && prevIndex === 11);
    	};

    	$$self.$set = $$props => {
    		if ("allowOverflow" in $$props) $$invalidate(18, allowOverflow = $$props.allowOverflow);
    		if ("cellGap" in $$props) $$invalidate(0, cellGap = $$props.cellGap);
    		if ("cellRadius" in $$props) $$invalidate(1, cellRadius = $$props.cellRadius);
    		if ("cellSize" in $$props) $$invalidate(2, cellSize = $$props.cellSize);
    		if ("colors" in $$props) $$invalidate(19, colors = $$props.colors);
    		if ("data" in $$props) $$invalidate(20, data = $$props.data);
    		if ("dayLabelWidth" in $$props) $$invalidate(3, dayLabelWidth = $$props.dayLabelWidth);
    		if ("dayLabels" in $$props) $$invalidate(4, dayLabels = $$props.dayLabels);
    		if ("emptyColor" in $$props) $$invalidate(21, emptyColor = $$props.emptyColor);
    		if ("endDate" in $$props) $$invalidate(22, endDate = $$props.endDate);
    		if ("fontColor" in $$props) $$invalidate(5, fontColor = $$props.fontColor);
    		if ("fontFamily" in $$props) $$invalidate(6, fontFamily = $$props.fontFamily);
    		if ("fontSize" in $$props) $$invalidate(7, fontSize = $$props.fontSize);
    		if ("monthGap" in $$props) $$invalidate(8, monthGap = $$props.monthGap);
    		if ("monthLabelHeight" in $$props) $$invalidate(9, monthLabelHeight = $$props.monthLabelHeight);
    		if ("monthLabels" in $$props) $$invalidate(10, monthLabels = $$props.monthLabels);
    		if ("startDate" in $$props) $$invalidate(23, startDate = $$props.startDate);
    		if ("view" in $$props) $$invalidate(11, view = $$props.view);
    	};

    	let cellRect;
    	let calendar;
    	let chunks;
    	let weekRect;
    	let height;
    	let width;
    	let dayLabelPosition;

    	$$self.$$.update = () => {
    		if ($$self.$$.dirty[0] & /*cellSize, cellGap*/ 5) {
    			 $$invalidate(12, cellRect = cellSize + cellGap);
    		}

    		if ($$self.$$.dirty[0] & /*allowOverflow, colors, data, emptyColor, endDate, startDate, view*/ 16517120) {
    			 $$invalidate(24, calendar = getCalendar({
    				allowOverflow,
    				colors,
    				data,
    				emptyColor,
    				endDate,
    				startDate,
    				view
    			}));
    		}

    		if ($$self.$$.dirty[0] & /*view, allowOverflow, calendar, endDate, startDate*/ 29624320) {
    			 $$invalidate(13, chunks = view === "monthly"
    			? chunkMonths({
    					allowOverflow,
    					calendar,
    					endDate,
    					startDate
    				})
    			: chunkWeeks({
    					allowOverflow,
    					calendar,
    					endDate,
    					startDate
    				}));
    		}

    		if ($$self.$$.dirty[0] & /*cellRect, cellGap*/ 4097) {
    			 $$invalidate(25, weekRect = 7 * cellRect - cellGap);
    		}

    		if ($$self.$$.dirty[0] & /*view, cellRect, cellGap, monthLabelHeight, weekRect*/ 33561089) {
    			 $$invalidate(14, height = view === "monthly"
    			? 6 * cellRect - cellGap + monthLabelHeight
    			: weekRect + monthLabelHeight); // <- max of 6 rows in monthly view
    		}

    		if ($$self.$$.dirty[0] & /*view, weekRect, monthGap, chunks, cellRect, cellGap, dayLabelWidth*/ 33569033) {
    			 $$invalidate(15, width = view === "monthly"
    			? (weekRect + monthGap) * chunks.length - monthGap
    			: cellRect * chunks.length - cellGap + dayLabelWidth);
    		}

    		if ($$self.$$.dirty[0] & /*cellRect, monthLabelHeight*/ 4608) {
    			 $$invalidate(16, dayLabelPosition = index => {
    				return cellRect * index + cellRect / 2 + monthLabelHeight;
    			});
    		}
    	};

    	return [
    		cellGap,
    		cellRadius,
    		cellSize,
    		dayLabelWidth,
    		dayLabels,
    		fontColor,
    		fontFamily,
    		fontSize,
    		monthGap,
    		monthLabelHeight,
    		monthLabels,
    		view,
    		cellRect,
    		chunks,
    		height,
    		width,
    		dayLabelPosition,
    		isNewMonth,
    		allowOverflow,
    		colors,
    		data,
    		emptyColor,
    		endDate,
    		startDate
    	];
    }

    class SvelteHeatmap extends internal.SvelteComponent {
    	constructor(options) {
    		super();

    		internal.init(
    			this,
    			options,
    			instance$3,
    			create_fragment$3,
    			internal.safe_not_equal,
    			{
    				allowOverflow: 18,
    				cellGap: 0,
    				cellRadius: 1,
    				cellSize: 2,
    				colors: 19,
    				data: 20,
    				dayLabelWidth: 3,
    				dayLabels: 4,
    				emptyColor: 21,
    				endDate: 22,
    				fontColor: 5,
    				fontFamily: 6,
    				fontSize: 7,
    				monthGap: 8,
    				monthLabelHeight: 9,
    				monthLabels: 10,
    				startDate: 23,
    				view: 11
    			},
    			[-1, -1]
    		);
    	}
    }

    SvelteHeatmap.VERSION = '1.0.1';

    return SvelteHeatmap;

})));
